@@ -1,7 +1,7 @@
 package Bencher::Scenario::RoleTinyCommonsTree::Startup;
 
-our $DATE = '2016-03-24'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2016-07-03'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 our $scenario = {
     summary => 'Benchmark startup overhead of some modules in '.
@@ -38,7 +38,7 @@ Bencher::Scenario::RoleTinyCommonsTree::Startup - Benchmark startup overhead of
 
 =head1 VERSION
 
-This document describes version 0.02 of Bencher::Scenario::RoleTinyCommonsTree::Startup (from Perl distribution Bencher-Scenarios-RoleTinyCommonsTree), released on 2016-03-24.
+This document describes version 0.03 of Bencher::Scenario::RoleTinyCommonsTree::Startup (from Perl distribution Bencher-Scenarios-RoleTinyCommonsTree), released on 2016-07-03.
 
 =head1 SYNOPSIS
 
@@ -52,17 +52,17 @@ For more options (dump scenario, list/include/exclude/add participants, list/inc
 
 Version numbers shown below are the versions used when running the sample benchmark.
 
-L<Code::Includable::Tree::FromStruct> 0.07
+L<Code::Includable::Tree::FromStruct> 0.10
 
-L<Code::Includable::Tree::NodeMethods> 0.07
+L<Code::Includable::Tree::NodeMethods> 0.10
 
-L<Role::TinyCommons::Tree::FromStruct> 0.07
+L<Role::TinyCommons::Tree::FromStruct> 0.10
 
-L<Role::TinyCommons::Tree::Node> 0.07
+L<Role::TinyCommons::Tree::Node> 0.10
 
-L<Role::TinyCommons::Tree::NodeMethods> 0.07
+L<Role::TinyCommons::Tree::NodeMethods> 0.10
 
-L<Scalar::Util> 1.42
+L<Scalar::Util> 1.45
 
 =head1 BENCHMARK PARTICIPANTS
 
@@ -108,20 +108,21 @@ L<Role::TinyCommons::Tree::NodeMethods>
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.22.0 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.22.2 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
 
 Benchmark with default options (C<< bencher -m RoleTinyCommonsTree::Startup >>):
 
+ #table1#
  +--------------------------------------+-----------+------------------------+------------+---------+---------+
- | participant                          | time (ms) | mod_overhead_time (ms) | vs_slowest | errors  | samples |
+ | participant                          | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
  +--------------------------------------+-----------+------------------------+------------+---------+---------+
- | Role::TinyCommons::Tree::NodeMethods | 13        | 8.4                    | 1          | 3.1e-05 | 20      |
- | Role::TinyCommons::Tree::FromStruct  | 10        | 5.4                    | 1.3        | 5.3e-05 | 20      |
- | Role::TinyCommons::Tree::Node        | 10        | 5.4                    | 1          | 0.00018 | 21      |
- | Code::Includable::Tree::NodeMethods  | 8.6       | 4                      | 1.5        | 5.9e-05 | 20      |
- | Scalar::Util                         | 7.3       | 2.7                    | 1.7        | 1e-05   | 20      |
- | Code::Includable::Tree::FromStruct   | 5.1       | 0.500000000000001      | 2.5        | 2.9e-05 | 20      |
- | perl -e1 (baseline)                  | 4.6       | 0                      | 2.7        | 2.7e-05 | 20      |
+ | Role::TinyCommons::Tree::FromStruct  |       9.2 |                    6.5 |        1   | 2.2e-05 |      21 |
+ | Role::TinyCommons::Tree::NodeMethods |       8.7 |                    6   |        1.1 | 8.2e-05 |      20 |
+ | Code::Includable::Tree::NodeMethods  |       6.3 |                    3.6 |        1.5 | 2.3e-05 |      21 |
+ | Role::TinyCommons::Tree::Node        |       6.2 |                    3.5 |        1.5 | 3.8e-05 |      20 |
+ | Scalar::Util                         |       6   |                    3.3 |        2   | 6.1e-05 |      20 |
+ | Code::Includable::Tree::FromStruct   |       3.1 |                    0.4 |        3   | 1.8e-05 |      20 |
+ | perl -e1 (baseline)                  |       2.7 |                    0   |        3.4 | 1.6e-05 |      20 |
  +--------------------------------------+-----------+------------------------+------------+---------+---------+
 
 =head1 DESCRIPTION
